#ifndef _DRIVERS_I2C_CHIPS_F75111_H
#define _DRIVERS_I2C_CHIPS_F75111_H

#define F75_CTRL			0x01
#define F75_CTRL_INIT			(1<<7)
#define F75_CTRL_EN_WDT10		(1<<5)
#define F75_CTRL_SMART_PM		(1<<1)
#define F75_CTRL_POWERDOWN		(1<<0)

#define F75_STATUS			0x02
#define F75_STATUS_POWERDOWN		(1<<3)
#define F75_STATUS_I2C_ADDR		(1<<1)


/*
 * The datasheet is talking about pin and
 * not gpio but to get more understandable
 * I'm using gpio
 */
#define F75_FUNC			0x03
#define F75_FUNC_IRQ_LEVEL		6
#define F75_FUNC_IRQ_MODE		5
#define F75_FUNC_GP12			3
#define F75_FUNC_GP11			2
#define F75_FUNC_GP10			0

#define F75_MODE1			0x04
#define F75_MODE1_GP27			7
#define F75_MODE1_GP15			6
#define F75_MODE1_GP14			5
#define F75_MODE1_GP22			4
#define F75_MODE1_GP21			3
#define F75_MODE1_GP20			2
#define F75_MODE1_GP17			1
#define F75_MODE1_GP16			0

#define F75_MODE2			0x05
#define F75_MODE2_GP23			3
#define F75_MODE2_GP24			2
#define F75_MODE2_GP25			1
#define F75_MODE2_GP26			0

#define F75_FREQ1			0x06
#define F75_FREQ2			0x07
#define F75_FREQ3			0x08
#define F75_FREQ4			0x09

#define F75111_GPIO_OUT_CTRL		0x00
#define F75111_GPIO_OUT_DATA		0x01
#define F75111_GPIO_INP_STATUS		0x02
#define F75111_GPIO_PULSE_CTRL		0x03
#define F75111_GPIO_PULSE_WIDTH		0x04
#define F75111_GPIO_PULLUP		0x05
#define F75111_GPIO_INP_DB		0x06
#define F75111_GPIO_PULSE_INV		0x07
#define F75111_GPIO_EDGE_EN		0x08
#define F75111_GPIO_EDGE_STATUS		0x09
#define F75111_GPIO_SMI_EN		0x0A
#define F75111_GPIO_OUT_DRIVE		0x0B
#define F75111_GPIO_DB_TIME		0x0C

#define F75_CHIPID1			0x5A
#define F75_CHIPID2			0x5B
#define F75_VERSION			0x5C
#define F75_VENDOR1			0x5D
#define F75_VENDOR2			0x5E

#define F75111_ID			0x0300
#define F75111_VER			0x10
#define FINTEC_ID			0x1934


/*
 * GPXX with XX in octal.
 */
enum {
	F75111_GP10 = 0,
	F75111_GP11,
	F75111_GP12,
	F75111_GP13,
	F75111_GP14,
	F75111_GP15,
	F75111_GP16,
	F75111_GP17,
	F75111_GP20,
	F75111_GP21,
	F75111_GP22,
	F75111_GP23,
	F75111_GP24,
	F75111_GP25,
	F75111_GP26,
	F75111_GP27,
	F75111_GP30,
	F75111_GP31,
	F75111_GP32,
	F75111_GP33,
};

enum {
	F75111_LED_TRISTATE = 0,
	F75111_LED_HALF_HZ,
	F75111_LED_HZ,
	F75111_LED_LOW
};
enum {
	F75111_PIN_MODE_GPIO = 0,
	F75111_PIN_MODE_LED,
	F75111_PIN_MODE_IRQ,
	F75111_PIN_MODE_WDTOUT,
	F75111_PIN_MODE_WD_OUT = 2
};

struct f75111_gpio {
	unsigned char pin;
	unsigned char mode;
};

struct f75111_pdata {
	unsigned gpio_base;
	struct f75111_gpio *gpios;
	int size;
	struct gpio_led_platform_data *leds_data;
	int (*init)(struct i2c_client *client, int gpio_base);
	int (*exit)(struct i2c_client *client, int gpio_base);
};
#endif
